# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
BRepFeat module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_brepfeat.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _BRepFeat
else:
    import _BRepFeat

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _BRepFeat.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _BRepFeat.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepFeat.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepFeat.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _BRepFeat.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _BRepFeat.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _BRepFeat.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _BRepFeat.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _BRepFeat.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _BRepFeat.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepFeat.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _BRepFeat.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _BRepFeat.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepFeat.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepFeat.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepFeat.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _BRepFeat.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _BRepFeat:
_BRepFeat.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _BRepFeat.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.BOPAlgo
import OCC.Core.TopTools
import OCC.Core.IntTools
import OCC.Core.BRepAdaptor
import OCC.Core.Adaptor3d
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.math
import OCC.Core.GeomAdaptor
import OCC.Core.Geom2dAdaptor
import OCC.Core.Bnd
import OCC.Core.BVH
import OCC.Core.Geom2dHatch
import OCC.Core.IntRes2d
import OCC.Core.HatchGen
import OCC.Core.Geom2dInt
import OCC.Core.IntCurve
import OCC.Core.Extrema
import OCC.Core.Intf
import OCC.Core.GeomAPI
import OCC.Core.Approx
import OCC.Core.AppCont
import OCC.Core.AppParCurves
import OCC.Core.BRepClass3d
import OCC.Core.IntCurveSurface
import OCC.Core.IntSurf
import OCC.Core.IntCurvesFace
import OCC.Core.IntPatch
import OCC.Core.IntAna
import OCC.Core.GeomInt
import OCC.Core.IntImp
import OCC.Core.ApproxInt
import OCC.Core.BOPDS
import OCC.Core.BRepTools
import OCC.Core.BRep
import OCC.Core.Poly
import OCC.Core.TShort
import OCC.Core.BOPTools
import OCC.Core.BRepBuilderAPI
import OCC.Core.TColGeom
import OCC.Core.LocOpe

from enum import IntEnum
from OCC.Core.Exception import *

BRepFeat_NoError = _BRepFeat.BRepFeat_NoError
BRepFeat_InvalidPlacement = _BRepFeat.BRepFeat_InvalidPlacement
BRepFeat_HoleTooLong = _BRepFeat.BRepFeat_HoleTooLong
BRepFeat_OK = _BRepFeat.BRepFeat_OK
BRepFeat_BadDirect = _BRepFeat.BRepFeat_BadDirect
BRepFeat_BadIntersect = _BRepFeat.BRepFeat_BadIntersect
BRepFeat_EmptyBaryCurve = _BRepFeat.BRepFeat_EmptyBaryCurve
BRepFeat_EmptyCutResult = _BRepFeat.BRepFeat_EmptyCutResult
BRepFeat_FalseSide = _BRepFeat.BRepFeat_FalseSide
BRepFeat_IncDirection = _BRepFeat.BRepFeat_IncDirection
BRepFeat_IncSlidFace = _BRepFeat.BRepFeat_IncSlidFace
BRepFeat_IncParameter = _BRepFeat.BRepFeat_IncParameter
BRepFeat_IncTypes = _BRepFeat.BRepFeat_IncTypes
BRepFeat_IntervalOverlap = _BRepFeat.BRepFeat_IntervalOverlap
BRepFeat_InvFirstShape = _BRepFeat.BRepFeat_InvFirstShape
BRepFeat_InvOption = _BRepFeat.BRepFeat_InvOption
BRepFeat_InvShape = _BRepFeat.BRepFeat_InvShape
BRepFeat_LocOpeNotDone = _BRepFeat.BRepFeat_LocOpeNotDone
BRepFeat_LocOpeInvNotDone = _BRepFeat.BRepFeat_LocOpeInvNotDone
BRepFeat_NoExtFace = _BRepFeat.BRepFeat_NoExtFace
BRepFeat_NoFaceProf = _BRepFeat.BRepFeat_NoFaceProf
BRepFeat_NoGluer = _BRepFeat.BRepFeat_NoGluer
BRepFeat_NoIntersectF = _BRepFeat.BRepFeat_NoIntersectF
BRepFeat_NoIntersectU = _BRepFeat.BRepFeat_NoIntersectU
BRepFeat_NoParts = _BRepFeat.BRepFeat_NoParts
BRepFeat_NoProjPt = _BRepFeat.BRepFeat_NoProjPt
BRepFeat_NotInitialized = _BRepFeat.BRepFeat_NotInitialized
BRepFeat_NotYetImplemented = _BRepFeat.BRepFeat_NotYetImplemented
BRepFeat_NullRealTool = _BRepFeat.BRepFeat_NullRealTool
BRepFeat_NullToolF = _BRepFeat.BRepFeat_NullToolF
BRepFeat_NullToolU = _BRepFeat.BRepFeat_NullToolU
BRepFeat_NoSelection = _BRepFeat.BRepFeat_NoSelection
BRepFeat_SelectionFU = _BRepFeat.BRepFeat_SelectionFU
BRepFeat_SelectionU = _BRepFeat.BRepFeat_SelectionU
BRepFeat_SelectionSh = _BRepFeat.BRepFeat_SelectionSh
BRepFeat_SelectionShU = _BRepFeat.BRepFeat_SelectionShU


class BRepFeat_Status(IntEnum):
	BRepFeat_NoError = 0
	BRepFeat_InvalidPlacement = 1
	BRepFeat_HoleTooLong = 2
BRepFeat_NoError = BRepFeat_Status.BRepFeat_NoError
BRepFeat_InvalidPlacement = BRepFeat_Status.BRepFeat_InvalidPlacement
BRepFeat_HoleTooLong = BRepFeat_Status.BRepFeat_HoleTooLong

class BRepFeat_StatusError(IntEnum):
	BRepFeat_OK = 0
	BRepFeat_BadDirect = 1
	BRepFeat_BadIntersect = 2
	BRepFeat_EmptyBaryCurve = 3
	BRepFeat_EmptyCutResult = 4
	BRepFeat_FalseSide = 5
	BRepFeat_IncDirection = 6
	BRepFeat_IncSlidFace = 7
	BRepFeat_IncParameter = 8
	BRepFeat_IncTypes = 9
	BRepFeat_IntervalOverlap = 10
	BRepFeat_InvFirstShape = 11
	BRepFeat_InvOption = 12
	BRepFeat_InvShape = 13
	BRepFeat_LocOpeNotDone = 14
	BRepFeat_LocOpeInvNotDone = 15
	BRepFeat_NoExtFace = 16
	BRepFeat_NoFaceProf = 17
	BRepFeat_NoGluer = 18
	BRepFeat_NoIntersectF = 19
	BRepFeat_NoIntersectU = 20
	BRepFeat_NoParts = 21
	BRepFeat_NoProjPt = 22
	BRepFeat_NotInitialized = 23
	BRepFeat_NotYetImplemented = 24
	BRepFeat_NullRealTool = 25
	BRepFeat_NullToolF = 26
	BRepFeat_NullToolU = 27
BRepFeat_OK = BRepFeat_StatusError.BRepFeat_OK
BRepFeat_BadDirect = BRepFeat_StatusError.BRepFeat_BadDirect
BRepFeat_BadIntersect = BRepFeat_StatusError.BRepFeat_BadIntersect
BRepFeat_EmptyBaryCurve = BRepFeat_StatusError.BRepFeat_EmptyBaryCurve
BRepFeat_EmptyCutResult = BRepFeat_StatusError.BRepFeat_EmptyCutResult
BRepFeat_FalseSide = BRepFeat_StatusError.BRepFeat_FalseSide
BRepFeat_IncDirection = BRepFeat_StatusError.BRepFeat_IncDirection
BRepFeat_IncSlidFace = BRepFeat_StatusError.BRepFeat_IncSlidFace
BRepFeat_IncParameter = BRepFeat_StatusError.BRepFeat_IncParameter
BRepFeat_IncTypes = BRepFeat_StatusError.BRepFeat_IncTypes
BRepFeat_IntervalOverlap = BRepFeat_StatusError.BRepFeat_IntervalOverlap
BRepFeat_InvFirstShape = BRepFeat_StatusError.BRepFeat_InvFirstShape
BRepFeat_InvOption = BRepFeat_StatusError.BRepFeat_InvOption
BRepFeat_InvShape = BRepFeat_StatusError.BRepFeat_InvShape
BRepFeat_LocOpeNotDone = BRepFeat_StatusError.BRepFeat_LocOpeNotDone
BRepFeat_LocOpeInvNotDone = BRepFeat_StatusError.BRepFeat_LocOpeInvNotDone
BRepFeat_NoExtFace = BRepFeat_StatusError.BRepFeat_NoExtFace
BRepFeat_NoFaceProf = BRepFeat_StatusError.BRepFeat_NoFaceProf
BRepFeat_NoGluer = BRepFeat_StatusError.BRepFeat_NoGluer
BRepFeat_NoIntersectF = BRepFeat_StatusError.BRepFeat_NoIntersectF
BRepFeat_NoIntersectU = BRepFeat_StatusError.BRepFeat_NoIntersectU
BRepFeat_NoParts = BRepFeat_StatusError.BRepFeat_NoParts
BRepFeat_NoProjPt = BRepFeat_StatusError.BRepFeat_NoProjPt
BRepFeat_NotInitialized = BRepFeat_StatusError.BRepFeat_NotInitialized
BRepFeat_NotYetImplemented = BRepFeat_StatusError.BRepFeat_NotYetImplemented
BRepFeat_NullRealTool = BRepFeat_StatusError.BRepFeat_NullRealTool
BRepFeat_NullToolF = BRepFeat_StatusError.BRepFeat_NullToolF
BRepFeat_NullToolU = BRepFeat_StatusError.BRepFeat_NullToolU

class BRepFeat_PerfSelection(IntEnum):
	BRepFeat_NoSelection = 0
	BRepFeat_SelectionFU = 1
	BRepFeat_SelectionU = 2
	BRepFeat_SelectionSh = 3
	BRepFeat_SelectionShU = 4
BRepFeat_NoSelection = BRepFeat_PerfSelection.BRepFeat_NoSelection
BRepFeat_SelectionFU = BRepFeat_PerfSelection.BRepFeat_SelectionFU
BRepFeat_SelectionU = BRepFeat_PerfSelection.BRepFeat_SelectionU
BRepFeat_SelectionSh = BRepFeat_PerfSelection.BRepFeat_SelectionSh
BRepFeat_SelectionShU = BRepFeat_PerfSelection.BRepFeat_SelectionShU

class brepfeat(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Barycenter(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        Pt: gp_Pnt

        Returns
        -------
        None

        """
        return _BRepFeat.brepfeat_Barycenter(*args)

    @staticmethod
    def FaceUntil(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        F: TopoDS_Face

        Returns
        -------
        None

        """
        return _BRepFeat.brepfeat_FaceUntil(*args)

    @staticmethod
    def IsInside(*args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        F1: TopoDS_Face
        F2: TopoDS_Face

        Returns
        -------
        bool

        """
        return _BRepFeat.brepfeat_IsInside(*args)

    @staticmethod
    def ParametricBarycenter(*args) -> "Standard_Real":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        C: Geom_Curve

        Returns
        -------
        float

        """
        return _BRepFeat.brepfeat_ParametricBarycenter(*args)

    @staticmethod
    def ParametricMinMax(*args) -> "Standard_Real &, Standard_Real &, Standard_Real &, Standard_Real &, Standard_Boolean &":
        r"""
        Ori = true taking account the orientation.

        Parameters
        ----------
        S: TopoDS_Shape
        C: Geom_Curve
        Ori: bool,optional
        	default value is Standard_False

        Returns
        -------
        prmin: float
        prmax: float
        prbmin: float
        prbmax: float
        flag: bool

        """
        return _BRepFeat.brepfeat_ParametricMinMax(*args)

    @staticmethod
    def SampleEdges(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        Pt: TColgp_SequenceOfPnt

        Returns
        -------
        None

        """
        return _BRepFeat.brepfeat_SampleEdges(*args)

    @staticmethod
    def Tool(*args) -> "TopoDS_Solid":
        r"""
        No available documentation.

        Parameters
        ----------
        SRef: TopoDS_Shape
        Fac: TopoDS_Face
        Orf: TopAbs_Orientation

        Returns
        -------
        TopoDS_Solid

        """
        return _BRepFeat.brepfeat_Tool(*args)

    __repr__ = _dumps_object

    @methodnotwrapped
    def IsInOut(self):
    	pass


    def __init__(self):
        _BRepFeat.brepfeat_swiginit(self, _BRepFeat.new_brepfeat())
    __swig_destroy__ = _BRepFeat.delete_brepfeat

# Register brepfeat in _BRepFeat:
_BRepFeat.brepfeat_swigregister(brepfeat)

def brepfeat_Barycenter(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    S: TopoDS_Shape
    Pt: gp_Pnt

    Returns
    -------
    None

    """
    return _BRepFeat.brepfeat_Barycenter(*args)

def brepfeat_FaceUntil(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    S: TopoDS_Shape
    F: TopoDS_Face

    Returns
    -------
    None

    """
    return _BRepFeat.brepfeat_FaceUntil(*args)

def brepfeat_IsInside(*args) -> "Standard_Boolean":
    r"""
    No available documentation.

    Parameters
    ----------
    F1: TopoDS_Face
    F2: TopoDS_Face

    Returns
    -------
    bool

    """
    return _BRepFeat.brepfeat_IsInside(*args)

def brepfeat_ParametricBarycenter(*args) -> "Standard_Real":
    r"""
    No available documentation.

    Parameters
    ----------
    S: TopoDS_Shape
    C: Geom_Curve

    Returns
    -------
    float

    """
    return _BRepFeat.brepfeat_ParametricBarycenter(*args)

def brepfeat_ParametricMinMax(*args) -> "Standard_Real &, Standard_Real &, Standard_Real &, Standard_Real &, Standard_Boolean &":
    r"""
    Ori = true taking account the orientation.

    Parameters
    ----------
    S: TopoDS_Shape
    C: Geom_Curve
    Ori: bool,optional
    	default value is Standard_False

    Returns
    -------
    prmin: float
    prmax: float
    prbmin: float
    prbmax: float
    flag: bool

    """
    return _BRepFeat.brepfeat_ParametricMinMax(*args)

def brepfeat_SampleEdges(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    S: TopoDS_Shape
    Pt: TColgp_SequenceOfPnt

    Returns
    -------
    None

    """
    return _BRepFeat.brepfeat_SampleEdges(*args)

def brepfeat_Tool(*args) -> "TopoDS_Solid":
    r"""
    No available documentation.

    Parameters
    ----------
    SRef: TopoDS_Shape
    Fac: TopoDS_Face
    Orf: TopAbs_Orientation

    Returns
    -------
    TopoDS_Solid

    """
    return _BRepFeat.brepfeat_Tool(*args)

class BRepFeat_Builder(OCC.Core.BOPAlgo.BOPAlgo_BOP):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _BRepFeat.BRepFeat_Builder_swiginit(self, _BRepFeat.new_BRepFeat_Builder(*args))

    def CheckSolidImages(self, *args) -> "void":
        r"""
        Collects the images of the object, that contains in the images of the tool.

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_Builder_CheckSolidImages(self, *args)

    def FillRemoved(self, *args) -> "void":
        r"""
        Collects the removed parts of the tool into myremoved map.

        Returns
        -------
        None
        Adds the shape s and its sub-shapes into myremoved map.

        Parameters
        ----------
        theS: TopoDS_Shape
        theM: TopTools_MapOfShape

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_Builder_FillRemoved(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialyzes the object of local boolean operation.

        Parameters
        ----------
        theShape: TopoDS_Shape

        Returns
        -------
        None
        Initialyzes the arguments of local boolean operation.

        Parameters
        ----------
        theShape: TopoDS_Shape
        theTool: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_Builder_Init(self, *args)

    def KeepPart(self, *args) -> "void":
        r"""
        Adds shape thes and all its sub-shapes into myshapes map.

        Parameters
        ----------
        theS: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_Builder_KeepPart(self, *args)

    def KeepParts(self, *args) -> "void":
        r"""
        Initialyzes parts of the tool for second step of algorithm. collects shapes and all sub-shapes into myshapes map.

        Parameters
        ----------
        theIm: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_Builder_KeepParts(self, *args)

    def PartsOfTool(self, *args) -> "void":
        r"""
        Collects parts of the tool.

        Parameters
        ----------
        theLT: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_Builder_PartsOfTool(self, *args)

    def PerformResult(self, *args) -> "void":
        r"""
        Main function to build the result of the local operation required.

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_Builder_PerformResult(self, *args)

    def RebuildEdge(self, *args) -> "void":
        r"""
        Rebuilds edges in accordance with the kept parts of the tool.

        Parameters
        ----------
        theE: TopoDS_Shape
        theF: TopoDS_Face
        theME: TopTools_MapOfShape
        aLEIm: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_Builder_RebuildEdge(self, *args)

    def RebuildFaces(self, *args) -> "void":
        r"""
        Rebuilds faces in accordance with the kept parts of the tool.

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_Builder_RebuildFaces(self, *args)

    def SetOperation(self, *args) -> "void":
        r"""
        Sets the operation of local boolean operation. if thefuse = 0 than the operation is cut, otherwise fuse.

        Parameters
        ----------
        theFuse: int

        Returns
        -------
        None
        Sets the operation of local boolean operation. if theflag = true it means that no selection of parts of the tool is needed, t.e. no second part. in that case if thefuse = 0 than operation is common, otherwise cut21. if theflag = false setoperation(thefuse) function is called.

        Parameters
        ----------
        theFuse: int
        theFlag: bool

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_Builder_SetOperation(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepFeat.delete_BRepFeat_Builder

# Register BRepFeat_Builder in _BRepFeat:
_BRepFeat.BRepFeat_Builder_swigregister(BRepFeat_Builder)

class BRepFeat_Form(OCC.Core.BRepBuilderAPI.BRepBuilderAPI_MakeShape):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def BarycCurve(self, *args) -> "opencascade::handle< Geom_Curve >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Geom_Curve>

        """
        return _BRepFeat.BRepFeat_Form_BarycCurve(self, *args)

    def BasisShapeValid(self, *args) -> "void":
        r"""
        Initializes the topological construction if the basis shape is present.

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_Form_BasisShapeValid(self, *args)

    def CurrentStatusError(self, *args) -> "BRepFeat_StatusError":
        r"""
        No available documentation.

        Returns
        -------
        BRepFeat_StatusError

        """
        return _BRepFeat.BRepFeat_Form_CurrentStatusError(self, *args)

    def Curves(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TColGeom_SequenceOfCurve

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_Form_Curves(self, *args)

    def FirstShape(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the list of shapes created at the bottom of the created form. it may be an empty list.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _BRepFeat.BRepFeat_Form_FirstShape(self, *args)

    def GeneratedShapeValid(self, *args) -> "void":
        r"""
        Initializes the topological construction if the generated shape s is present.

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_Form_GeneratedShapeValid(self, *args)

    def GluedFacesValid(self, *args) -> "void":
        r"""
        Initializes the topological construction if the glued face is present.

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_Form_GluedFacesValid(self, *args)

    def LastShape(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the list of shapes created at the top of the created form. it may be an empty list.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _BRepFeat.BRepFeat_Form_LastShape(self, *args)

    def NewEdges(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns a list of the limiting and glueing edges generated by the feature. these edges did not originally exist in the basis shape. the list provides the information necessary for subsequent addition of fillets. it may be an empty list.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _BRepFeat.BRepFeat_Form_NewEdges(self, *args)

    def PerfSelectionValid(self, *args) -> "void":
        r"""
        Initializes the topological construction if the selected face is present.

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_Form_PerfSelectionValid(self, *args)

    def ShapeFromValid(self, *args) -> "void":
        r"""
        Initializes the topological construction if the shape is present from the specified integer on.

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_Form_ShapeFromValid(self, *args)

    def ShapeUntilValid(self, *args) -> "void":
        r"""
        Initializes the topological construction if the shape is present until the specified integer.

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_Form_ShapeUntilValid(self, *args)

    def SketchFaceValid(self, *args) -> "void":
        r"""
        Initializes the topological construction if the sketch face is present. if the sketch face is inside the basis shape, local operations such as glueing can be performed.

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_Form_SketchFaceValid(self, *args)

    def TgtEdges(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns a list of the tangent edges among the limiting and glueing edges generated by the feature. these edges did not originally exist in the basis shape and are tangent to the face against which the feature is built. the list provides the information necessary for subsequent addition of fillets. it may be an empty list. if an edge is tangent, no fillet is possible, and the edge must subsequently be removed if you want to add a fillet.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _BRepFeat.BRepFeat_Form_TgtEdges(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepFeat.delete_BRepFeat_Form

# Register BRepFeat_Form in _BRepFeat:
_BRepFeat.BRepFeat_Form_swigregister(BRepFeat_Form)

class BRepFeat_Gluer(OCC.Core.BRepBuilderAPI.BRepBuilderAPI_MakeShape):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initializes an empty constructor.

        Returns
        -------
        None
        Initializes the shapes to be glued, the new shape snew and the basis shape sbase.

        Parameters
        ----------
        Snew: TopoDS_Shape
        Sbase: TopoDS_Shape

        Returns
        -------
        None

        """
        _BRepFeat.BRepFeat_Gluer_swiginit(self, _BRepFeat.new_BRepFeat_Gluer(*args))

    def BasisShape(self, *args) -> "TopoDS_Shape const":
        r"""
        Returns the basis shape of the compound shape.

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepFeat.BRepFeat_Gluer_BasisShape(self, *args)

    def Bind(self, *args) -> "void":
        r"""
        Defines a contact between fnew on the new shape snew and fbase on the basis shape sbase. informs other methods that fnew in the new shape snew is connected to the face fbase in the basis shape sbase. the contact faces of the glued shape must not have parts outside the contact faces of the basis shape. this indicates that glueing is possible.

        Parameters
        ----------
        Fnew: TopoDS_Face
        Fbase: TopoDS_Face

        Returns
        -------
        None
        Nforms other methods that the edge enew in the new shape is the same as the edge ebase in the basis shape and is therefore attached to the basis shape. this indicates that glueing is possible.

        Parameters
        ----------
        Enew: TopoDS_Edge
        Ebase: TopoDS_Edge

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_Gluer_Bind(self, *args)

    def GluedShape(self, *args) -> "TopoDS_Shape const":
        r"""
        Returns the resulting compound shape.

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepFeat.BRepFeat_Gluer_GluedShape(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initializes the new shape snew and the basis shape sbase for the local glueing operation.

        Parameters
        ----------
        Snew: TopoDS_Shape
        Sbase: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_Gluer_Init(self, *args)

    def OpeType(self, *args) -> "LocOpe_Operation":
        r"""
        Determine which operation type to use glueing or sliding.

        Returns
        -------
        LocOpe_Operation

        """
        return _BRepFeat.BRepFeat_Gluer_OpeType(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepFeat.delete_BRepFeat_Gluer

# Register BRepFeat_Gluer in _BRepFeat:
_BRepFeat.BRepFeat_Gluer_swigregister(BRepFeat_Gluer)

class BRepFeat_RibSlot(OCC.Core.BRepBuilderAPI.BRepBuilderAPI_MakeShape):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def ChoiceOfFaces(*args) -> "TopoDS_Face":
        r"""
        No available documentation.

        Parameters
        ----------
        faces: TopTools_ListOfShape
        cc: Geom_Curve
        par: float
        bnd: float
        Pln: Geom_Plane

        Returns
        -------
        TopoDS_Face

        """
        return _BRepFeat.BRepFeat_RibSlot_ChoiceOfFaces(*args)

    def CurrentStatusError(self, *args) -> "BRepFeat_StatusError":
        r"""
        No available documentation.

        Returns
        -------
        BRepFeat_StatusError

        """
        return _BRepFeat.BRepFeat_RibSlot_CurrentStatusError(self, *args)

    def FacesForDraft(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns a list of the limiting and glueing faces generated by the feature. these faces did not originally exist in the basis shape. the list provides the information necessary for subsequent addition of a draft to a face. it may be an empty list. if a face has tangent edges, no draft is possible, and the tangent edges must subsequently be removed if you want to add a draft to the face.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _BRepFeat.BRepFeat_RibSlot_FacesForDraft(self, *args)

    def FirstShape(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the list of shapes created at the bottom of the created form. it may be an empty list.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _BRepFeat.BRepFeat_RibSlot_FirstShape(self, *args)

    @staticmethod
    def IntPar(*args) -> "Standard_Real":
        r"""
        No available documentation.

        Parameters
        ----------
        C: Geom_Curve
        P: gp_Pnt

        Returns
        -------
        float

        """
        return _BRepFeat.BRepFeat_RibSlot_IntPar(*args)

    def LastShape(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the list of shapes created at the top of the created form. it may be an empty list.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _BRepFeat.BRepFeat_RibSlot_LastShape(self, *args)

    def NewEdges(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns a list of the limiting and glueing edges generated by the feature. these edges did not originally exist in the basis shape. the list provides the information necessary for subsequent addition of fillets. it may be an empty list.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _BRepFeat.BRepFeat_RibSlot_NewEdges(self, *args)

    def TgtEdges(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns a list of the tangent edges among the limiting and glueing edges generated by the feature. these edges did not originally exist in the basis shape and are tangent to the face against which the feature is built. the list provides the information necessary for subsequent addition of fillets. it may be an empty list. if an edge is tangent, no fillet is possible, and the edge must subsequently be removed if you want to add a fillet.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _BRepFeat.BRepFeat_RibSlot_TgtEdges(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepFeat.delete_BRepFeat_RibSlot

# Register BRepFeat_RibSlot in _BRepFeat:
_BRepFeat.BRepFeat_RibSlot_swigregister(BRepFeat_RibSlot)

def BRepFeat_RibSlot_ChoiceOfFaces(*args) -> "TopoDS_Face":
    r"""
    No available documentation.

    Parameters
    ----------
    faces: TopTools_ListOfShape
    cc: Geom_Curve
    par: float
    bnd: float
    Pln: Geom_Plane

    Returns
    -------
    TopoDS_Face

    """
    return _BRepFeat.BRepFeat_RibSlot_ChoiceOfFaces(*args)

def BRepFeat_RibSlot_IntPar(*args) -> "Standard_Real":
    r"""
    No available documentation.

    Parameters
    ----------
    C: Geom_Curve
    P: gp_Pnt

    Returns
    -------
    float

    """
    return _BRepFeat.BRepFeat_RibSlot_IntPar(*args)

class BRepFeat_SplitShape(OCC.Core.BRepBuilderAPI.BRepBuilderAPI_MakeShape):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None
        Creates the process with the shape <s>.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None

        """
        _BRepFeat.BRepFeat_SplitShape_swiginit(self, _BRepFeat.new_BRepFeat_SplitShape(*args))

    def Add(self, *args) -> "void":
        r"""
        Add splitting edges or wires for whole initial shape withot additional specification edge->face, edge->edge this method puts edge on the corresponding faces from initial shape.

        Parameters
        ----------
        theEdges: TopTools_SequenceOfShape

        Returns
        -------
        bool
        Adds the wire <w> on the face <f>. raises nosuchobject if <f> does not belong to the original shape.

        Parameters
        ----------
        W: TopoDS_Wire
        F: TopoDS_Face

        Returns
        -------
        None
        Adds the edge <e> on the face <f>.

        Parameters
        ----------
        E: TopoDS_Edge
        F: TopoDS_Face

        Returns
        -------
        None
        Adds the compound <comp> on the face <f>. the compound <comp> must consist of edges lying on the face <f>. if edges are geometrically connected, they must be connected topologically, i.e. they must share common vertices. //! raises nosuchobject if <f> does not belong to the original shape.

        Parameters
        ----------
        Comp: TopoDS_Compound
        F: TopoDS_Face

        Returns
        -------
        None
        Adds the edge <e> on the existing edge <eon>.

        Parameters
        ----------
        E: TopoDS_Edge
        EOn: TopoDS_Edge

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_SplitShape_Add(self, *args)

    def DirectLeft(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the faces which are the left of the projected wires.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _BRepFeat.BRepFeat_SplitShape_DirectLeft(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initializes the process on the shape <s>.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_SplitShape_Init(self, *args)

    def Left(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the faces of the 'left' part on the shape. (it is build from directleft, with the faces connected to this set, and so on...). raises notdone if isdone returns <standard_false>.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _BRepFeat.BRepFeat_SplitShape_Left(self, *args)

    def Right(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the faces of the 'right' part on the shape.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _BRepFeat.BRepFeat_SplitShape_Right(self, *args)

    def SetCheckInterior(self, *args) -> "void":
        r"""
        Set the flag of check internal intersections default value is true (to check).

        Parameters
        ----------
        ToCheckInterior: bool

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_SplitShape_SetCheckInterior(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepFeat.delete_BRepFeat_SplitShape

# Register BRepFeat_SplitShape in _BRepFeat:
_BRepFeat.BRepFeat_SplitShape_swigregister(BRepFeat_SplitShape)

class BRepFeat_MakeCylindricalHole(BRepFeat_Builder):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _BRepFeat.BRepFeat_MakeCylindricalHole_swiginit(self, _BRepFeat.new_BRepFeat_MakeCylindricalHole(*args))

    def Build(self, *args) -> "void":
        r"""
        Builds the resulting shape (redefined from makeshape). invalidates the given parts of tools if any, and performs the result of the local operation.

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeCylindricalHole_Build(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Sets the axis of the hole(s).

        Parameters
        ----------
        Axis: gp_Ax1

        Returns
        -------
        None
        Sets the shape and axis on which hole(s) will be performed.

        Parameters
        ----------
        S: TopoDS_Shape
        Axis: gp_Ax1

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeCylindricalHole_Init(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Performs every holes of radius <radius>. this command has the same effect as a cut operation with an infinite cylinder defined by the given axis and <radius>.

        Parameters
        ----------
        Radius: float

        Returns
        -------
        None
        Performs evry hole of radius <radius> located between pfrom and pto on the given axis. if <withcontrol> is set to standard_false no control are done on the resulting shape after the operation is performed.

        Parameters
        ----------
        Radius: float
        PFrom: float
        PTo: float
        WithControl: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeCylindricalHole_Perform(self, *args)

    def PerformBlind(self, *args) -> "void":
        r"""
        Performs a blind hole of radius <radius> and length <length>. the length is measured from the origin of the given axis. if <withcontrol> is set to standard_false no control are done after the operation is performed.

        Parameters
        ----------
        Radius: float
        Length: float
        WithControl: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeCylindricalHole_PerformBlind(self, *args)

    def PerformThruNext(self, *args) -> "void":
        r"""
        Performs the first hole of radius <radius>, in the direction of the defined axis. first hole signify first encountered after the origin of the axis. if <withcontrol> is set to standard_false no control are done on the resulting shape after the operation is performed.

        Parameters
        ----------
        Radius: float
        WithControl: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeCylindricalHole_PerformThruNext(self, *args)

    def PerformUntilEnd(self, *args) -> "void":
        r"""
        Performs evry holes of radius <radius> located after the origin of the given axis. if <withcontrol> is set to standard_false no control are done on the resulting shape after the operation is performed.

        Parameters
        ----------
        Radius: float
        WithControl: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeCylindricalHole_PerformUntilEnd(self, *args)

    def Status(self, *args) -> "BRepFeat_Status":
        r"""
        Returns the status after a hole is performed.

        Returns
        -------
        BRepFeat_Status

        """
        return _BRepFeat.BRepFeat_MakeCylindricalHole_Status(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepFeat.delete_BRepFeat_MakeCylindricalHole

# Register BRepFeat_MakeCylindricalHole in _BRepFeat:
_BRepFeat.BRepFeat_MakeCylindricalHole_swigregister(BRepFeat_MakeCylindricalHole)

class BRepFeat_MakeDPrism(BRepFeat_Form):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        A face pbase is selected in the shape sbase to serve as the basis for the draft prism. the draft will be defined by the angle angle and fuse offers a choice between: - removing matter with a boolean cut using the setting 0 - adding matter with boolean fusion using the setting 1. the sketch face skface serves to determine the type of operation. if it is inside the basis shape, a local operation such as glueing can be performed. initializes the draft prism class.

        Parameters
        ----------
        Sbase: TopoDS_Shape
        Pbase: TopoDS_Face
        Skface: TopoDS_Face
        Angle: float
        Fuse: int
        Modify: bool

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        None

        """
        _BRepFeat.BRepFeat_MakeDPrism_swiginit(self, _BRepFeat.new_BRepFeat_MakeDPrism(*args))

    def Add(self, *args) -> "void":
        r"""
        Indicates that the edge <e> will slide on the face <onface>. raises constructionerror if the face does not belong to the basis shape, or the edge to the prismed shape.

        Parameters
        ----------
        E: TopoDS_Edge
        OnFace: TopoDS_Face

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeDPrism_Add(self, *args)

    def BossEdges(self, *args) -> "void":
        r"""
        Determination of topedges and latedges. sig = 1 -> topedges = firstshape of the dprism sig = 2 -> topedges = lastshape of the dprism.

        Parameters
        ----------
        sig: int

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeDPrism_BossEdges(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initializes this algorithm for building draft prisms along surfaces. a face pbase is selected in the basis shape sbase to serve as the basis from the draft prism. the draft will be defined by the angle angle and fuse offers a choice between: - removing matter with a boolean cut using the setting 0 - adding matter with boolean fusion using the setting 1. the sketch face skface serves to determine the type of operation. if it is inside the basis shape, a local operation such as glueing can be performed.

        Parameters
        ----------
        Sbase: TopoDS_Shape
        Pbase: TopoDS_Face
        Skface: TopoDS_Face
        Angle: float
        Fuse: int
        Modify: bool

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeDPrism_Init(self, *args)

    def LatEdges(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the list of topods edges of the bottom of the boss.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _BRepFeat.BRepFeat_MakeDPrism_LatEdges(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Height: float

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Until: TopoDS_Shape

        Returns
        -------
        None
        Assigns one of the following semantics - to a height height - to a face until - from a face from to a height until. reconstructs the feature topologically according to the semantic option chosen.

        Parameters
        ----------
        From: TopoDS_Shape
        Until: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeDPrism_Perform(self, *args)

    def PerformFromEnd(self, *args) -> "void":
        r"""
        Realizes a semi-infinite prism, limited by the face funtil.

        Parameters
        ----------
        FUntil: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeDPrism_PerformFromEnd(self, *args)

    def PerformThruAll(self, *args) -> "void":
        r"""
        Builds an infinite prism. the infinite descendants will not be kept in the result.

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeDPrism_PerformThruAll(self, *args)

    def PerformUntilEnd(self, *args) -> "void":
        r"""
        Realizes a semi-infinite prism, limited by the position of the prism base.

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeDPrism_PerformUntilEnd(self, *args)

    def PerformUntilHeight(self, *args) -> "void":
        r"""
        Assigns both a limiting shape, until from topods_shape, and a height, height at which to stop generation of the prism feature.

        Parameters
        ----------
        Until: TopoDS_Shape
        Height: float

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeDPrism_PerformUntilHeight(self, *args)

    def TopEdges(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the list of topods edges of the top of the boss.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _BRepFeat.BRepFeat_MakeDPrism_TopEdges(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepFeat.delete_BRepFeat_MakeDPrism

# Register BRepFeat_MakeDPrism in _BRepFeat:
_BRepFeat.BRepFeat_MakeDPrism_swigregister(BRepFeat_MakeDPrism)

class BRepFeat_MakeLinearForm(BRepFeat_RibSlot):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initializes the linear form class.

        Returns
        -------
        None
        Contour w, a shape sbase and a plane p are initialized to serve as the basic elements in the construction of the rib or groove. direction and direction1 give the vectors for defining the direction(s) in which thickness will be built up. fuse offers a choice between: - removing matter with a boolean cut using the setting 0 in case of the groove - adding matter with boolean fusion using the setting 1 in case of the rib.

        Parameters
        ----------
        Sbase: TopoDS_Shape
        W: TopoDS_Wire
        P: Geom_Plane
        Direction: gp_Vec
        Direction1: gp_Vec
        Fuse: int
        Modify: bool

        Returns
        -------
        None

        """
        _BRepFeat.BRepFeat_MakeLinearForm_swiginit(self, _BRepFeat.new_BRepFeat_MakeLinearForm(*args))

    def Add(self, *args) -> "void":
        r"""
        Indicates that the edge <e> will slide on the face <onface>. raises constructionerror if the face does not belong to the basis shape, or the edge to the prismed shape.

        Parameters
        ----------
        E: TopoDS_Edge
        OnFace: TopoDS_Face

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeLinearForm_Add(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initializes this construction algorithm. a contour w, a shape sbase and a plane p are initialized to serve as the basic elements in the construction of the rib or groove. the vectors for defining the direction(s) in which thickness will be built up are given by direction and direction1. fuse offers a choice between: - removing matter with a boolean cut using the setting 0 in case of the groove - adding matter with boolean fusion using the setting 1 in case of the rib.

        Parameters
        ----------
        Sbase: TopoDS_Shape
        W: TopoDS_Wire
        P: Geom_Plane
        Direction: gp_Vec
        Direction1: gp_Vec
        Fuse: int
        Modify: bool

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeLinearForm_Init(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Performs a prism from the wire to the plane along the basis shape sbase. reconstructs the feature topologically.

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeLinearForm_Perform(self, *args)

    def Propagate(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        L: TopTools_ListOfShape
        F: TopoDS_Face
        FPoint: gp_Pnt
        LPoint: gp_Pnt

        Returns
        -------
        falseside: bool

        """
        return _BRepFeat.BRepFeat_MakeLinearForm_Propagate(self, *args)

    __repr__ = _dumps_object

    @methodnotwrapped
    def TransformShapeFU(self):
    	pass

    __swig_destroy__ = _BRepFeat.delete_BRepFeat_MakeLinearForm

# Register BRepFeat_MakeLinearForm in _BRepFeat:
_BRepFeat.BRepFeat_MakeLinearForm_swigregister(BRepFeat_MakeLinearForm)

class BRepFeat_MakePipe(BRepFeat_Form):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initializes the pipe class.

        Returns
        -------
        None
        A face pbase is selected in the shape sbase to serve as the basis for the pipe. it will be defined by the wire spine. fuse offers a choice between: - removing matter with a boolean cut using the setting 0 - adding matter with boolean fusion using the setting 1. the sketch face skface serves to determine the type of operation. if it is inside the basis shape, a local operation such as glueing can be performed.

        Parameters
        ----------
        Sbase: TopoDS_Shape
        Pbase: TopoDS_Shape
        Skface: TopoDS_Face
        Spine: TopoDS_Wire
        Fuse: int
        Modify: bool

        Returns
        -------
        None

        """
        _BRepFeat.BRepFeat_MakePipe_swiginit(self, _BRepFeat.new_BRepFeat_MakePipe(*args))

    def Add(self, *args) -> "void":
        r"""
        Indicates that the edge <e> will slide on the face <onface>. raises constructionerror if the face does not belong to the basis shape, or the edge to the prismed shape.

        Parameters
        ----------
        E: TopoDS_Edge
        OnFace: TopoDS_Face

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakePipe_Add(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initializes this algorithm for adding pipes to shapes. a face pbase is selected in the shape sbase to serve as the basis for the pipe. it will be defined by the wire spine. fuse offers a choice between: - removing matter with a boolean cut using the setting 0 - adding matter with boolean fusion using the setting 1. the sketch face skface serves to determine the type of operation. if it is inside the basis shape, a local operation such as glueing can be performed.

        Parameters
        ----------
        Sbase: TopoDS_Shape
        Pbase: TopoDS_Shape
        Skface: TopoDS_Face
        Spine: TopoDS_Wire
        Fuse: int
        Modify: bool

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakePipe_Init(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Until: TopoDS_Shape

        Returns
        -------
        None
        Assigns one of the following semantics - to a face until - from a face from to a height until. reconstructs the feature topologically according to the semantic option chosen.

        Parameters
        ----------
        From: TopoDS_Shape
        Until: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakePipe_Perform(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepFeat.delete_BRepFeat_MakePipe

# Register BRepFeat_MakePipe in _BRepFeat:
_BRepFeat.BRepFeat_MakePipe_swigregister(BRepFeat_MakePipe)

class BRepFeat_MakePrism(BRepFeat_Form):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Builds a prism by projecting a wire along the face of a shape. initializes the prism class.

        Returns
        -------
        None
        Builds a prism by projecting a wire along the face of a shape. a face pbase is selected in the shape sbase to serve as the basis for the prism. the orientation of the prism will be defined by the vector direction. fuse offers a choice between: - removing matter with a boolean cut using the setting 0 - adding matter with boolean fusion using the setting 1. the sketch face skface serves to determine the type of operation. if it is inside the basis shape, a local operation such as glueing can be performed. exceptions standard_constructionerror if the face does not belong to the basis or the prism shape.

        Parameters
        ----------
        Sbase: TopoDS_Shape
        Pbase: TopoDS_Shape
        Skface: TopoDS_Face
        Direction: gp_Dir
        Fuse: int
        Modify: bool

        Returns
        -------
        None

        """
        _BRepFeat.BRepFeat_MakePrism_swiginit(self, _BRepFeat.new_BRepFeat_MakePrism(*args))

    def Add(self, *args) -> "void":
        r"""
        Indicates that the edge <e> will slide on the face <onface>. raises constructionerror if the face does not belong to the basis shape, or the edge to the prismed shape.

        Parameters
        ----------
        E: TopoDS_Edge
        OnFace: TopoDS_Face

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakePrism_Add(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initializes this algorithm for building prisms along surfaces. a face pbase is selected in the shape sbase to serve as the basis for the prism. the orientation of the prism will be defined by the vector direction. fuse offers a choice between: - removing matter with a boolean cut using the setting 0 - adding matter with boolean fusion using the setting 1. the sketch face skface serves to determine the type of operation. if it is inside the basis shape, a local operation such as glueing can be performed.

        Parameters
        ----------
        Sbase: TopoDS_Shape
        Pbase: TopoDS_Shape
        Skface: TopoDS_Face
        Direction: gp_Dir
        Fuse: int
        Modify: bool

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakePrism_Init(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Length: float

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Until: TopoDS_Shape

        Returns
        -------
        None
        Assigns one of the following semantics - to a height length - to a face until - from a face from to a height until. reconstructs the feature topologically according to the semantic option chosen.

        Parameters
        ----------
        From: TopoDS_Shape
        Until: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakePrism_Perform(self, *args)

    def PerformFromEnd(self, *args) -> "void":
        r"""
        Realizes a semi-infinite prism, limited by the face funtil.

        Parameters
        ----------
        FUntil: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakePrism_PerformFromEnd(self, *args)

    def PerformThruAll(self, *args) -> "void":
        r"""
        Builds an infinite prism. the infinite descendants will not be kept in the result.

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakePrism_PerformThruAll(self, *args)

    def PerformUntilEnd(self, *args) -> "void":
        r"""
        Realizes a semi-infinite prism, limited by the position of the prism base. all other faces extend infinitely.

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakePrism_PerformUntilEnd(self, *args)

    def PerformUntilHeight(self, *args) -> "void":
        r"""
        Assigns both a limiting shape, until from topods_shape, and a height, length at which to stop generation of the prism feature.

        Parameters
        ----------
        Until: TopoDS_Shape
        Length: float

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakePrism_PerformUntilHeight(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepFeat.delete_BRepFeat_MakePrism

# Register BRepFeat_MakePrism in _BRepFeat:
_BRepFeat.BRepFeat_MakePrism_swigregister(BRepFeat_MakePrism)

class BRepFeat_MakeRevol(BRepFeat_Form):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initializes the revolved shell class.

        Returns
        -------
        None
        A face pbase is selected in the shape sbase to serve as the basis for the revolved shell. the revolution will be defined by the axis axis and fuse offers a choice between: - removing matter with a boolean cut using the setting 0 - adding matter with boolean fusion using the setting 1. the sketch face skface serves to determine the type of operation. if it is inside the basis shape, a local operation such as glueing can be performed.

        Parameters
        ----------
        Sbase: TopoDS_Shape
        Pbase: TopoDS_Shape
        Skface: TopoDS_Face
        Axis: gp_Ax1
        Fuse: int
        Modify: bool

        Returns
        -------
        None

        """
        _BRepFeat.BRepFeat_MakeRevol_swiginit(self, _BRepFeat.new_BRepFeat_MakeRevol(*args))

    def Add(self, *args) -> "void":
        r"""
        Indicates that the edge <e> will slide on the face <onface>. raises constructionerror if the face does not belong to the basis shape, or the edge to the prismed shape.

        Parameters
        ----------
        E: TopoDS_Edge
        OnFace: TopoDS_Face

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeRevol_Add(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Sbase: TopoDS_Shape
        Pbase: TopoDS_Shape
        Skface: TopoDS_Face
        Axis: gp_Ax1
        Fuse: int
        Modify: bool

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeRevol_Init(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Angle: float

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Until: TopoDS_Shape

        Returns
        -------
        None
        Reconstructs the feature topologically.

        Parameters
        ----------
        From: TopoDS_Shape
        Until: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeRevol_Perform(self, *args)

    def PerformThruAll(self, *args) -> "void":
        r"""
        Builds an infinite shell. the infinite descendants will not be kept in the result.

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeRevol_PerformThruAll(self, *args)

    def PerformUntilAngle(self, *args) -> "void":
        r"""
        Assigns both a limiting shape, until from topods_shape, and an angle, angle at which to stop generation of the revolved shell feature.

        Parameters
        ----------
        Until: TopoDS_Shape
        Angle: float

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeRevol_PerformUntilAngle(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepFeat.delete_BRepFeat_MakeRevol

# Register BRepFeat_MakeRevol in _BRepFeat:
_BRepFeat.BRepFeat_MakeRevol_swigregister(BRepFeat_MakeRevol)

class BRepFeat_MakeRevolutionForm(BRepFeat_RibSlot):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initializes the linear form class.

        Returns
        -------
        None
        A contour w, a shape sbase and a plane p are initialized to serve as the basic elements in the construction of the rib or groove. the axis axis of the revolved surface in the basis shape defines the feature's axis of revolution. height1 and height2 may be used as limits to the construction of the feature. fuse offers a choice between: - removing matter with a boolean cut using the setting 0 in case of the groove - adding matter with boolean fusion using the setting 1 in case of the rib.

        Parameters
        ----------
        Sbase: TopoDS_Shape
        W: TopoDS_Wire
        Plane: Geom_Plane
        Axis: gp_Ax1
        Height1: float
        Height2: float
        Fuse: int

        Returns
        -------
        Sliding: bool

        """
        _BRepFeat.BRepFeat_MakeRevolutionForm_swiginit(self, _BRepFeat.new_BRepFeat_MakeRevolutionForm(*args))

    def Add(self, *args) -> "void":
        r"""
        Indicates that the edge <e> will slide on the face <onface>. raises constructionerror if the face does not belong to the basis shape, or the edge to the prismed shape.

        Parameters
        ----------
        E: TopoDS_Edge
        OnFace: TopoDS_Face

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeRevolutionForm_Add(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initializes this construction algorithm a contour w, a shape sbase and a plane p are initialized to serve as the basic elements in the construction of the rib or groove. the axis axis of the revolved surface in the basis shape defines the feature's axis of revolution. height1 and height2 may be used as limits to the construction of the feature. fuse offers a choice between: - removing matter with a boolean cut using the setting 0 in case of the groove - adding matter with boolean fusion using the setting 1 in case of the rib.

        Parameters
        ----------
        Sbase: TopoDS_Shape
        W: TopoDS_Wire
        Plane: Geom_Plane
        Axis: gp_Ax1
        Height1: float
        Height2: float
        Fuse: int

        Returns
        -------
        Sliding: bool

        """
        return _BRepFeat.BRepFeat_MakeRevolutionForm_Init(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Performs a prism from the wire to the plane along the basis shape s. reconstructs the feature topologically.

        Returns
        -------
        None

        """
        return _BRepFeat.BRepFeat_MakeRevolutionForm_Perform(self, *args)

    def Propagate(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        L: TopTools_ListOfShape
        F: TopoDS_Face
        FPoint: gp_Pnt
        LPoint: gp_Pnt

        Returns
        -------
        falseside: bool

        """
        return _BRepFeat.BRepFeat_MakeRevolutionForm_Propagate(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepFeat.delete_BRepFeat_MakeRevolutionForm

# Register BRepFeat_MakeRevolutionForm in _BRepFeat:
_BRepFeat.BRepFeat_MakeRevolutionForm_swigregister(BRepFeat_MakeRevolutionForm)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Interface import *
from OCC.Core.TCollection import *
from OCC.Core.gp import *
from OCC.Core.TColStd import *
from OCC.Core.Message import *


class IGESData_Array1OfDirPart:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> IGESData_DirPart: ...
    def __setitem__(self, index: int, value: IGESData_DirPart) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[IGESData_DirPart]: ...
    def next(self) -> IGESData_DirPart: ...
    __next__ = next
    def Init(self, theValue: IGESData_DirPart) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> IGESData_DirPart: ...
    def Last(self) -> IGESData_DirPart: ...
    def Value(self, theIndex: int) -> IGESData_DirPart: ...
    def SetValue(self, theIndex: int, theValue: IGESData_DirPart) -> None: ...

class IGESData_Array1OfIGESEntity:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class IGESData_ReadStage(IntEnum):
	IGESData_ReadDir: int = ...
	IGESData_ReadOwn: int = ...
	IGESData_ReadAssocs: int = ...
	IGESData_ReadProps: int = ...
	IGESData_ReadEnd: int = ...
IGESData_ReadDir = IGESData_ReadStage.IGESData_ReadDir
IGESData_ReadOwn = IGESData_ReadStage.IGESData_ReadOwn
IGESData_ReadAssocs = IGESData_ReadStage.IGESData_ReadAssocs
IGESData_ReadProps = IGESData_ReadStage.IGESData_ReadProps
IGESData_ReadEnd = IGESData_ReadStage.IGESData_ReadEnd

class IGESData_DefList(IntEnum):
	IGESData_DefNone: int = ...
	IGESData_DefOne: int = ...
	IGESData_DefSeveral: int = ...
	IGESData_ErrorOne: int = ...
	IGESData_ErrorSeveral: int = ...
IGESData_DefNone = IGESData_DefList.IGESData_DefNone
IGESData_DefOne = IGESData_DefList.IGESData_DefOne
IGESData_DefSeveral = IGESData_DefList.IGESData_DefSeveral
IGESData_ErrorOne = IGESData_DefList.IGESData_ErrorOne
IGESData_ErrorSeveral = IGESData_DefList.IGESData_ErrorSeveral

class IGESData_Status(IntEnum):
	IGESData_EntityOK: int = ...
	IGESData_EntityError: int = ...
	IGESData_ReferenceError: int = ...
	IGESData_TypeError: int = ...
IGESData_EntityOK = IGESData_Status.IGESData_EntityOK
IGESData_EntityError = IGESData_Status.IGESData_EntityError
IGESData_ReferenceError = IGESData_Status.IGESData_ReferenceError
IGESData_TypeError = IGESData_Status.IGESData_TypeError

class IGESData_DefType(IntEnum):
	IGESData_DefVoid: int = ...
	IGESData_DefValue: int = ...
	IGESData_DefReference: int = ...
	IGESData_DefAny: int = ...
	IGESData_ErrorVal: int = ...
	IGESData_ErrorRef: int = ...
IGESData_DefVoid = IGESData_DefType.IGESData_DefVoid
IGESData_DefValue = IGESData_DefType.IGESData_DefValue
IGESData_DefReference = IGESData_DefType.IGESData_DefReference
IGESData_DefAny = IGESData_DefType.IGESData_DefAny
IGESData_ErrorVal = IGESData_DefType.IGESData_ErrorVal
IGESData_ErrorRef = IGESData_DefType.IGESData_ErrorRef

class igesdata:
	@staticmethod
	def Init() -> None: ...
	@staticmethod
	def Protocol() -> IGESData_Protocol: ...

class IGESData_BasicEditor:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, protocol: IGESData_Protocol) -> None: ...
	@overload
	def __init__(self, model: IGESData_IGESModel, protocol: IGESData_Protocol) -> None: ...
	def ApplyUnit(self, enforce: Optional[bool] = False) -> None: ...
	def AutoCorrect(self, ent: IGESData_IGESEntity) -> bool: ...
	def AutoCorrectModel(self) -> int: ...
	def ComputeStatus(self) -> None: ...
	@staticmethod
	def DraftingMax() -> int: ...
	@staticmethod
	def DraftingName(flag: int) -> str: ...
	@staticmethod
	def IGESVersionMax() -> int: ...
	@staticmethod
	def IGESVersionName(flag: int) -> str: ...
	@overload
	def Init(self, protocol: IGESData_Protocol) -> None: ...
	@overload
	def Init(self, model: IGESData_IGESModel, protocol: IGESData_Protocol) -> None: ...
	def Model(self) -> IGESData_IGESModel: ...
	def SetUnitFlag(self, flag: int) -> bool: ...
	def SetUnitName(self, name: str) -> bool: ...
	def SetUnitValue(self, val: float) -> bool: ...
	@staticmethod
	def UnitFlagName(flag: int) -> str: ...
	@staticmethod
	def UnitFlagValue(flag: int) -> float: ...
	@staticmethod
	def UnitNameFlag(name: str) -> int: ...

class IGESData_DefSwitch:
	def __init__(self) -> None: ...
	def DefType(self) -> IGESData_DefType: ...
	def SetRank(self, val: int) -> None: ...
	def SetReference(self) -> None: ...
	def SetVoid(self) -> None: ...
	def Value(self) -> int: ...

class IGESData_DirChecker:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, atype: int) -> None: ...
	@overload
	def __init__(self, atype: int, aform: int) -> None: ...
	@overload
	def __init__(self, atype: int, aform1: int, aform2: int) -> None: ...
	def BlankStatusIgnored(self) -> None: ...
	def BlankStatusRequired(self, val: int) -> None: ...
	def Check(self, ach: Interface_Check, ent: IGESData_IGESEntity) -> None: ...
	def CheckTypeAndForm(self, ach: Interface_Check, ent: IGESData_IGESEntity) -> None: ...
	def Color(self, crit: IGESData_DefType) -> None: ...
	def Correct(self, ent: IGESData_IGESEntity) -> bool: ...
	def GraphicsIgnored(self, hierarchy: Optional[int] = -1) -> None: ...
	def HierarchyStatusIgnored(self) -> None: ...
	def HierarchyStatusRequired(self, val: int) -> None: ...
	def IsSet(self) -> bool: ...
	def LineFont(self, crit: IGESData_DefType) -> None: ...
	def LineWeight(self, crit: IGESData_DefType) -> None: ...
	def SetDefault(self) -> None: ...
	def Structure(self, crit: IGESData_DefType) -> None: ...
	def SubordinateStatusIgnored(self) -> None: ...
	def SubordinateStatusRequired(self, val: int) -> None: ...
	def UseFlagIgnored(self) -> None: ...
	def UseFlagRequired(self, val: int) -> None: ...

class IGESData_DirPart:
	def __init__(self) -> None: ...
	def Init(self, i1: int, i2: int, i3: int, i4: int, i5: int, i6: int, i7: int, i8: int, i9: int, i19: int, i11: int, i12: int, i13: int, i14: int, i15: int, i16: int, i17: int, res1: str, res2: str, label: str, subscript: str) -> None: ...
	def Type(self) -> IGESData_IGESType: ...
	def Values(self, res1: str, res2: str, label: str, subscript: str) -> Tuple[int, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int]: ...

class IGESData_FileRecognizer(Standard_Transient):
	def Add(self, reco: IGESData_FileRecognizer) -> None: ...
	def Evaluate(self, akey: IGESData_IGESType, res: IGESData_IGESEntity) -> bool: ...
	def Result(self) -> IGESData_IGESEntity: ...

class IGESData_GeneralModule(Interface_GeneralModule):
	def CanCopy(self, CN: int, ent: Standard_Transient) -> bool: ...
	def CheckCase(self, CN: int, ent: Standard_Transient, shares: Interface_ShareTool, ach: Interface_Check) -> None: ...
	def CopyCase(self, CN: int, entfrom: Standard_Transient, entto: Standard_Transient, TC: Interface_CopyTool) -> None: ...
	def DirChecker(self, CN: int, ent: IGESData_IGESEntity) -> IGESData_DirChecker: ...
	def FillSharedCase(self, CN: int, ent: Standard_Transient, iter: Interface_EntityIterator) -> None: ...
	def ListImpliedCase(self, CN: int, ent: Standard_Transient, iter: Interface_EntityIterator) -> None: ...
	def Name(self, CN: int, ent: Standard_Transient, shares: Interface_ShareTool) -> TCollection_HAsciiString: ...
	def NewVoid(self, CN: int, entto: Standard_Transient) -> bool: ...
	def OwnCheckCase(self, CN: int, ent: IGESData_IGESEntity, shares: Interface_ShareTool, ach: Interface_Check) -> None: ...
	def OwnCopyCase(self, CN: int, entfrom: IGESData_IGESEntity, entto: IGESData_IGESEntity, TC: Interface_CopyTool) -> None: ...
	def OwnDeleteCase(self, CN: int, ent: IGESData_IGESEntity) -> None: ...
	def OwnImpliedCase(self, CN: int, ent: IGESData_IGESEntity, iter: Interface_EntityIterator) -> None: ...
	def OwnRenewCase(self, CN: int, entfrom: IGESData_IGESEntity, entto: IGESData_IGESEntity, TC: Interface_CopyTool) -> None: ...
	def OwnSharedCase(self, CN: int, ent: IGESData_IGESEntity, iter: Interface_EntityIterator) -> None: ...
	def RenewImpliedCase(self, CN: int, entfrom: Standard_Transient, entto: Standard_Transient, TC: Interface_CopyTool) -> None: ...
	def WhenDeleteCase(self, CN: int, ent: Standard_Transient, dispatched: bool) -> None: ...

class IGESData_GlobalNodeOfSpecificLib(Standard_Transient):
	def __init__(self) -> None: ...
	def Add(self, amodule: IGESData_SpecificModule, aprotocol: IGESData_Protocol) -> None: ...
	def Module(self) -> IGESData_SpecificModule: ...
	def Next(self) -> IGESData_GlobalNodeOfSpecificLib: ...
	def Protocol(self) -> IGESData_Protocol: ...

class IGESData_GlobalNodeOfWriterLib(Standard_Transient):
	def __init__(self) -> None: ...
	def Add(self, amodule: IGESData_ReadWriteModule, aprotocol: IGESData_Protocol) -> None: ...
	def Module(self) -> IGESData_ReadWriteModule: ...
	def Next(self) -> IGESData_GlobalNodeOfWriterLib: ...
	def Protocol(self) -> IGESData_Protocol: ...

class IGESData_GlobalSection:
	def __init__(self) -> None: ...
	def ApplicationProtocol(self) -> TCollection_HAsciiString: ...
	def AuthorName(self) -> TCollection_HAsciiString: ...
	def CompanyName(self) -> TCollection_HAsciiString: ...
	def CopyRefs(self) -> None: ...
	def Date(self) -> TCollection_HAsciiString: ...
	def DraftingStandard(self) -> int: ...
	def EndMark(self) -> str: ...
	def FileName(self) -> TCollection_HAsciiString: ...
	def HasApplicationProtocol(self) -> bool: ...
	def HasLastChangeDate(self) -> bool: ...
	def HasMaxCoord(self) -> bool: ...
	def IGESVersion(self) -> int: ...
	def Init(self, params: Interface_ParamSet, ach: Interface_Check) -> None: ...
	def IntegerBits(self) -> int: ...
	def InterfaceVersion(self) -> TCollection_HAsciiString: ...
	def LastChangeDate(self) -> TCollection_HAsciiString: ...
	def LineWeightGrad(self) -> int: ...
	def MaxCoord(self) -> float: ...
	def MaxDigitsDouble(self) -> int: ...
	def MaxDigitsSingle(self) -> int: ...
	def MaxLineWeight(self) -> float: ...
	def MaxMaxCoord(self, val: Optional[float] = 0.0) -> None: ...
	def MaxMaxCoords(self, xyz: gp_XYZ) -> None: ...
	def MaxPower10Double(self) -> int: ...
	def MaxPower10Single(self) -> int: ...
	@overload
	@staticmethod
	def NewDateString(year: int, month: int, day: int, hour: int, minut: int, second: int, mode: Optional[int] = -1) -> TCollection_HAsciiString: ...
	@overload
	@staticmethod
	def NewDateString(date: TCollection_HAsciiString, mode: Optional[int] = 1) -> TCollection_HAsciiString: ...
	def Params(self) -> Interface_ParamSet: ...
	def ReceiveName(self) -> TCollection_HAsciiString: ...
	def Resolution(self) -> float: ...
	def Scale(self) -> float: ...
	def SendName(self) -> TCollection_HAsciiString: ...
	def Separator(self) -> str: ...
	def SetApplicationProtocol(self, val: TCollection_HAsciiString) -> None: ...
	def SetAuthorName(self, val: TCollection_HAsciiString) -> None: ...
	def SetCompanyName(self, val: TCollection_HAsciiString) -> None: ...
	def SetDate(self, val: TCollection_HAsciiString) -> None: ...
	def SetDraftingStandard(self, val: int) -> None: ...
	def SetEndMark(self, val: str) -> None: ...
	def SetFileName(self, val: TCollection_HAsciiString) -> None: ...
	def SetIGESVersion(self, val: int) -> None: ...
	def SetIntegerBits(self, val: int) -> None: ...
	def SetInterfaceVersion(self, val: TCollection_HAsciiString) -> None: ...
	@overload
	def SetLastChangeDate(self) -> None: ...
	@overload
	def SetLastChangeDate(self, val: TCollection_HAsciiString) -> None: ...
	def SetLineWeightGrad(self, val: int) -> None: ...
	def SetMaxCoord(self, val: Optional[float] = 0.0) -> None: ...
	def SetMaxDigitsDouble(self, val: int) -> None: ...
	def SetMaxDigitsSingle(self, val: int) -> None: ...
	def SetMaxLineWeight(self, val: float) -> None: ...
	def SetMaxPower10Double(self, val: int) -> None: ...
	def SetMaxPower10Single(self, val: int) -> None: ...
	def SetReceiveName(self, val: TCollection_HAsciiString) -> None: ...
	def SetResolution(self, val: float) -> None: ...
	def SetScale(self, val: float) -> None: ...
	def SetSendName(self, val: TCollection_HAsciiString) -> None: ...
	def SetSeparator(self, val: str) -> None: ...
	def SetSystemId(self, val: TCollection_HAsciiString) -> None: ...
	def SetUnitFlag(self, val: int) -> None: ...
	def SetUnitName(self, val: TCollection_HAsciiString) -> None: ...
	def SystemId(self) -> TCollection_HAsciiString: ...
	def TranslatedFromHollerith(self, astr: TCollection_HAsciiString) -> TCollection_HAsciiString: ...
	def UnitFlag(self) -> int: ...
	def UnitName(self) -> TCollection_HAsciiString: ...
	def UnitValue(self) -> float: ...

class IGESData_IGESDumper:
	def __init__(self, model: IGESData_IGESModel, protocol: IGESData_Protocol) -> None: ...

class IGESData_IGESEntity(Standard_Transient):
	def AddProperty(self, ent: IGESData_IGESEntity) -> None: ...
	def ArePresentAssociativities(self) -> bool: ...
	def ArePresentProperties(self) -> bool: ...
	def Associate(self, ent: IGESData_IGESEntity) -> None: ...
	def Associativities(self) -> Interface_EntityIterator: ...
	def BlankStatus(self) -> int: ...
	def CResValues(self, res1: str, res2: str) -> bool: ...
	def Color(self) -> IGESData_ColorEntity: ...
	def CompoundLocation(self) -> gp_GTrsf: ...
	def DefColor(self) -> IGESData_DefType: ...
	def DefLevel(self) -> IGESData_DefList: ...
	def DefLineFont(self) -> IGESData_DefType: ...
	def DefView(self) -> IGESData_DefList: ...
	def DirFieldEntity(self, fieldnum: int) -> IGESData_IGESEntity: ...
	def Dissociate(self, ent: IGESData_IGESEntity) -> None: ...
	def FormNumber(self) -> int: ...
	def HasLabelDisplay(self) -> bool: ...
	def HasName(self) -> bool: ...
	def HasOneParent(self) -> bool: ...
	def HasShortLabel(self) -> bool: ...
	def HasStructure(self) -> bool: ...
	def HasSubScriptNumber(self) -> bool: ...
	def HasTransf(self) -> bool: ...
	def HierarchyStatus(self) -> int: ...
	def IGESType(self) -> IGESData_IGESType: ...
	def InitColor(self, ent: IGESData_ColorEntity, rank: Optional[int] = 0) -> None: ...
	def InitDirFieldEntity(self, fieldnum: int, ent: IGESData_IGESEntity) -> None: ...
	def InitLevel(self, ent: IGESData_LevelListEntity, val: Optional[int] = 0) -> None: ...
	def InitLineFont(self, ent: IGESData_LineFontEntity, rank: Optional[int] = 0) -> None: ...
	def InitMisc(self, str: IGESData_IGESEntity, lab: IGESData_LabelDisplayEntity, weightnum: int) -> None: ...
	def InitStatus(self, blank: int, subordinate: int, useflag: int, hierarchy: int) -> None: ...
	def InitTransf(self, ent: IGESData_TransfEntity) -> None: ...
	def InitView(self, ent: IGESData_ViewKindEntity) -> None: ...
	def LabelDisplay(self) -> IGESData_LabelDisplayEntity: ...
	def Level(self) -> int: ...
	def LevelList(self) -> IGESData_LevelListEntity: ...
	def LineFont(self) -> IGESData_LineFontEntity: ...
	def LineWeight(self) -> float: ...
	def LineWeightNumber(self) -> int: ...
	def Location(self) -> gp_GTrsf: ...
	def NameValue(self) -> TCollection_HAsciiString: ...
	def NbAssociativities(self) -> int: ...
	def NbProperties(self) -> int: ...
	def NbTypedAssociativities(self, atype: Standard_Type) -> int: ...
	def NbTypedProperties(self, atype: Standard_Type) -> int: ...
	def Properties(self) -> Interface_EntityIterator: ...
	def RankColor(self) -> int: ...
	def RankLineFont(self) -> int: ...
	def RemoveProperty(self, ent: IGESData_IGESEntity) -> None: ...
	def SetLabel(self, label: TCollection_HAsciiString, sub: Optional[int] = -1) -> None: ...
	def SetLineWeight(self, defw: float, maxw: float, gradw: int) -> None: ...
	def ShortLabel(self) -> TCollection_HAsciiString: ...
	def SingleView(self) -> IGESData_ViewKindEntity: ...
	def Structure(self) -> IGESData_IGESEntity: ...
	def SubScriptNumber(self) -> int: ...
	def SubordinateStatus(self) -> int: ...
	def Transf(self) -> IGESData_TransfEntity: ...
	def TypeNumber(self) -> int: ...
	def TypedAssociativity(self, atype: Standard_Type) -> IGESData_IGESEntity: ...
	def TypedProperty(self, atype: Standard_Type, anum: Optional[int] = 0) -> IGESData_IGESEntity: ...
	def UniqueParent(self) -> IGESData_IGESEntity: ...
	def UseFlag(self) -> int: ...
	def VectorLocation(self) -> gp_GTrsf: ...
	def View(self) -> IGESData_ViewKindEntity: ...
	def ViewList(self) -> IGESData_ViewKindEntity: ...

class IGESData_IGESModel(Interface_InterfaceModel):
	def __init__(self) -> None: ...
	def AddStartLine(self, line: str, atnum: Optional[int] = 0) -> None: ...
	def ApplyStatic(self, param: Optional[str] = "") -> bool: ...
	def ClearHeader(self) -> None: ...
	def ClearLabels(self) -> None: ...
	def ClearStartSection(self) -> None: ...
	def DNum(self, ent: IGESData_IGESEntity) -> int: ...
	def Entity(self, num: int) -> IGESData_IGESEntity: ...
	def GetFromAnother(self, other: Interface_InterfaceModel) -> None: ...
	def GlobalSection(self) -> IGESData_GlobalSection: ...
	def NbStartLines(self) -> int: ...
	def NewEmptyModel(self) -> Interface_InterfaceModel: ...
	def SetGlobalSection(self, header: IGESData_GlobalSection) -> None: ...
	def SetLineWeights(self, defw: float) -> None: ...
	def SetStartSection(self, list: TColStd_HSequenceOfHAsciiString, copy: Optional[bool] = True) -> None: ...
	def StartLine(self, num: int) -> str: ...
	def StartSection(self) -> TColStd_HSequenceOfHAsciiString: ...
	def StringLabel(self, ent: Standard_Transient) -> TCollection_HAsciiString: ...
	def VerifyCheck(self, ach: Interface_Check) -> None: ...

class IGESData_IGESReaderData(Interface_FileReaderData):
	def __init__(self, nbe: int, nbp: int) -> None: ...
	def AddGlobal(self, atype: Interface_ParamType, aval: str) -> None: ...
	def AddStartLine(self, aval: str) -> None: ...
	def DefaultLineWeight(self) -> float: ...
	def DirPart(self, num: int) -> IGESData_DirPart: ...
	def DirType(self, num: int) -> IGESData_IGESType: ...
	def DirValues(self, num: int, res1: str, res2: str, label: str, subs: str) -> Tuple[int, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int]: ...
	def FindNextRecord(self, num: int) -> int: ...
	def GlobalCheck(self) -> Interface_Check: ...
	def GlobalSection(self) -> IGESData_GlobalSection: ...
	def NbEntities(self) -> int: ...
	def SetDefaultLineWeight(self, defw: float) -> None: ...
	def SetDirPart(self, num: int, i1: int, i2: int, i3: int, i4: int, i5: int, i6: int, i7: int, i8: int, i9: int, i10: int, i11: int, i12: int, i13: int, i14: int, i15: int, i16: int, i17: int, res1: str, res2: str, label: str, subs: str) -> None: ...
	def SetEntityNumbers(self) -> None: ...
	def SetGlobalSection(self) -> None: ...
	def StartSection(self) -> TColStd_HSequenceOfHAsciiString: ...

class IGESData_IGESReaderTool(Interface_FileReaderTool):
	def __init__(self, reader: IGESData_IGESReaderData, protocol: IGESData_Protocol) -> None: ...
	def AnalyseRecord(self, num: int, anent: Standard_Transient, acheck: Interface_Check) -> bool: ...
	def BeginRead(self, amodel: Interface_InterfaceModel) -> None: ...
	def EndRead(self, amodel: Interface_InterfaceModel) -> None: ...
	def Prepare(self, reco: IGESData_FileRecognizer) -> None: ...
	def ReadAssocs(self, ent: IGESData_IGESEntity, IR: IGESData_IGESReaderData, PR: IGESData_ParamReader) -> None: ...
	def ReadDir(self, ent: IGESData_IGESEntity, IR: IGESData_IGESReaderData, DP: IGESData_DirPart, ach: Interface_Check) -> None: ...
	def ReadOwnParams(self, ent: IGESData_IGESEntity, IR: IGESData_IGESReaderData, PR: IGESData_ParamReader) -> None: ...
	def ReadProps(self, ent: IGESData_IGESEntity, IR: IGESData_IGESReaderData, PR: IGESData_ParamReader) -> None: ...
	def Recognize(self, num: int, ach: Interface_Check, ent: Standard_Transient) -> bool: ...

class IGESData_IGESType:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, atype: int, aform: int) -> None: ...
	def Form(self) -> int: ...
	def IsEqual(self, another: IGESData_IGESType) -> bool: ...
	def Nullify(self) -> None: ...
	def Type(self) -> int: ...

class IGESData_IGESWriter:
	@overload
	def __init__(self, amodel: IGESData_IGESModel) -> None: ...
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, other: IGESData_IGESWriter) -> None: ...
	def Associativities(self, anent: IGESData_IGESEntity) -> None: ...
	def DirPart(self, anent: IGESData_IGESEntity) -> None: ...
	def EndEntity(self) -> None: ...
	def FloatWriter(self) -> Interface_FloatWriter: ...
	def OwnParams(self, anent: IGESData_IGESEntity) -> None: ...
	def Properties(self, anent: IGESData_IGESEntity) -> None: ...
	def SectionG(self, header: IGESData_GlobalSection) -> None: ...
	def SectionS(self) -> None: ...
	def SectionStrings(self, numsec: int) -> TColStd_HSequenceOfHAsciiString: ...
	def SectionT(self) -> None: ...
	def SectionsDP(self) -> None: ...
	def SendBoolean(self, val: bool) -> None: ...
	def SendModel(self, protocol: IGESData_Protocol) -> None: ...
	def SendStartLine(self, startline: str) -> None: ...
	def SendString(self, val: TCollection_HAsciiString) -> None: ...
	def SendVoid(self) -> None: ...
	def GetWriteMode(self) -> int: ...
	def SetWriteMode(self, value: int) -> None: ...

class IGESData_NodeOfSpecificLib(Standard_Transient):
	def __init__(self) -> None: ...
	def AddNode(self, anode: IGESData_GlobalNodeOfSpecificLib) -> None: ...
	def Module(self) -> IGESData_SpecificModule: ...
	def Next(self) -> IGESData_NodeOfSpecificLib: ...
	def Protocol(self) -> IGESData_Protocol: ...

class IGESData_NodeOfWriterLib(Standard_Transient):
	def __init__(self) -> None: ...
	def AddNode(self, anode: IGESData_GlobalNodeOfWriterLib) -> None: ...
	def Module(self) -> IGESData_ReadWriteModule: ...
	def Next(self) -> IGESData_NodeOfWriterLib: ...
	def Protocol(self) -> IGESData_Protocol: ...

class IGESData_ParamCursor:
	@overload
	def __init__(self, num: int) -> None: ...
	@overload
	def __init__(self, num: int, nb: int, size: Optional[int] = 1) -> None: ...
	def Advance(self) -> bool: ...
	def Count(self) -> int: ...
	def ItemSize(self) -> int: ...
	def Limit(self) -> int: ...
	def Offset(self) -> int: ...
	def SetAdvance(self, advance: bool) -> None: ...
	def SetOne(self, autoadv: Optional[bool] = True) -> None: ...
	def SetTerm(self, size: int, autoadv: Optional[bool] = True) -> None: ...
	def SetXY(self, autoadv: Optional[bool] = True) -> None: ...
	def SetXYZ(self, autoadv: Optional[bool] = True) -> None: ...
	def Start(self) -> int: ...
	def TermSize(self) -> int: ...

class IGESData_ParamReader:
	def __init__(self, list: Interface_ParamList, ach: Interface_Check, base: Optional[int] = 1, nbpar: Optional[int] = 0, num: Optional[int] = 0) -> None: ...
	@overload
	def AddFail(self, afail: str, bfail: Optional[str] = "") -> None: ...
	@overload
	def AddFail(self, af: TCollection_HAsciiString, bf: TCollection_HAsciiString) -> None: ...
	@overload
	def AddWarning(self, awarn: str, bwarn: Optional[str] = "") -> None: ...
	@overload
	def AddWarning(self, aw: TCollection_HAsciiString, bw: TCollection_HAsciiString) -> None: ...
	def CCheck(self) -> Interface_Check: ...
	def Check(self) -> Interface_Check: ...
	def Clear(self) -> None: ...
	def Current(self) -> IGESData_ParamCursor: ...
	def CurrentList(self, nb: int, size: Optional[int] = 1) -> IGESData_ParamCursor: ...
	def CurrentNumber(self) -> int: ...
	def DefinedElseSkip(self) -> bool: ...
	def EndAll(self) -> None: ...
	def EntityNumber(self) -> int: ...
	def HasFailed(self) -> bool: ...
	def IsCheckEmpty(self) -> bool: ...
	def IsParamDefined(self, num: int) -> bool: ...
	def IsParamEntity(self, num: int) -> bool: ...
	def Mend(self, pref: Optional[str] = "") -> None: ...
	def NbParams(self) -> int: ...
	def NextStage(self) -> None: ...
	def ParamEntity(self, IR: IGESData_IGESReaderData, num: int) -> IGESData_IGESEntity: ...
	def ParamNumber(self, num: int) -> int: ...
	def ParamType(self, num: int) -> Interface_ParamType: ...
	def ParamValue(self, num: int) -> str: ...
	@overload
	def ReadBoolean(self, PC: IGESData_ParamCursor, amsg: Message_Msg, exact: Optional[bool] = True) -> Tuple[bool, bool]: ...
	@overload
	def ReadBoolean(self, PC: IGESData_ParamCursor, mess: str, exact: Optional[bool] = True) -> Tuple[bool, bool]: ...
	@overload
	def ReadEntList(self, IR: IGESData_IGESReaderData, PC: IGESData_ParamCursor, amsg: Message_Msg, val: Interface_EntityList, ord: Optional[bool] = True) -> bool: ...
	@overload
	def ReadEntList(self, IR: IGESData_IGESReaderData, PC: IGESData_ParamCursor, mess: str, val: Interface_EntityList, ord: Optional[bool] = True) -> bool: ...
	@overload
	def ReadEnts(self, IR: IGESData_IGESReaderData, PC: IGESData_ParamCursor, amsg: Message_Msg, val: IGESData_HArray1OfIGESEntity, index: Optional[int] = 1) -> bool: ...
	@overload
	def ReadEnts(self, IR: IGESData_IGESReaderData, PC: IGESData_ParamCursor, mess: str, val: IGESData_HArray1OfIGESEntity, index: Optional[int] = 1) -> bool: ...
	@overload
	def ReadInteger(self, PC: IGESData_ParamCursor) -> Tuple[bool, int]: ...
	@overload
	def ReadInteger(self, PC: IGESData_ParamCursor, mess: str) -> Tuple[bool, int]: ...
	@overload
	def ReadInts(self, PC: IGESData_ParamCursor, amsg: Message_Msg, val: TColStd_HArray1OfInteger, index: Optional[int] = 1) -> bool: ...
	@overload
	def ReadInts(self, PC: IGESData_ParamCursor, mess: str, val: TColStd_HArray1OfInteger, index: Optional[int] = 1) -> bool: ...
	@overload
	def ReadReal(self, PC: IGESData_ParamCursor) -> Tuple[bool, float]: ...
	@overload
	def ReadReal(self, PC: IGESData_ParamCursor, mess: str) -> Tuple[bool, float]: ...
	@overload
	def ReadReals(self, PC: IGESData_ParamCursor, amsg: Message_Msg, val: TColStd_HArray1OfReal, index: Optional[int] = 1) -> bool: ...
	@overload
	def ReadReals(self, PC: IGESData_ParamCursor, mess: str, val: TColStd_HArray1OfReal, index: Optional[int] = 1) -> bool: ...
	@overload
	def ReadText(self, PC: IGESData_ParamCursor, amsg: Message_Msg, val: TCollection_HAsciiString) -> bool: ...
	@overload
	def ReadText(self, PC: IGESData_ParamCursor, mess: str, val: TCollection_HAsciiString) -> bool: ...
	@overload
	def ReadTexts(self, PC: IGESData_ParamCursor, amsg: Message_Msg, val: Interface_HArray1OfHAsciiString, index: Optional[int] = 1) -> bool: ...
	@overload
	def ReadTexts(self, PC: IGESData_ParamCursor, mess: str, val: Interface_HArray1OfHAsciiString, index: Optional[int] = 1) -> bool: ...
	@overload
	def ReadXY(self, PC: IGESData_ParamCursor, amsg: Message_Msg, val: gp_XY) -> bool: ...
	@overload
	def ReadXY(self, PC: IGESData_ParamCursor, mess: str, val: gp_XY) -> bool: ...
	@overload
	def ReadXYZ(self, PC: IGESData_ParamCursor, amsg: Message_Msg, val: gp_XYZ) -> bool: ...
	@overload
	def ReadXYZ(self, PC: IGESData_ParamCursor, mess: str, val: gp_XYZ) -> bool: ...
	@overload
	def ReadingEntityNumber(self, num: int) -> Tuple[bool, int]: ...
	@overload
	def ReadingEntityNumber(self, num: int, mess: str) -> Tuple[bool, int]: ...
	@overload
	def ReadingReal(self, num: int) -> Tuple[bool, float]: ...
	@overload
	def ReadingReal(self, num: int, mess: str) -> Tuple[bool, float]: ...
	def SendFail(self, amsg: Message_Msg) -> None: ...
	def SendWarning(self, amsg: Message_Msg) -> None: ...
	def SetCurrentNumber(self, num: int) -> None: ...
	def Stage(self) -> IGESData_ReadStage: ...

class IGESData_Protocol(Interface_Protocol):
	def __init__(self) -> None: ...
	def IsSuitableModel(self, model: Interface_InterfaceModel) -> bool: ...
	def IsUnknownEntity(self, ent: Standard_Transient) -> bool: ...
	def NbResources(self) -> int: ...
	def NewModel(self) -> Interface_InterfaceModel: ...
	def Resource(self, num: int) -> Interface_Protocol: ...
	def TypeNumber(self, atype: Standard_Type) -> int: ...
	def UnknownEntity(self) -> Standard_Transient: ...

class IGESData_ReadWriteModule(Interface_ReaderModule):
	def CaseIGES(self, typenum: int, formnum: int) -> int: ...
	def CaseNum(self, data: Interface_FileReaderData, num: int) -> int: ...
	def Read(self, CN: int, data: Interface_FileReaderData, num: int, ach: Interface_Check, ent: Standard_Transient) -> None: ...
	def ReadOwnParams(self, CN: int, ent: IGESData_IGESEntity, IR: IGESData_IGESReaderData, PR: IGESData_ParamReader) -> None: ...
	def WriteOwnParams(self, CN: int, ent: IGESData_IGESEntity, IW: IGESData_IGESWriter) -> None: ...

class IGESData_SpecificLib:
	@overload
	def __init__(self, aprotocol: IGESData_Protocol) -> None: ...
	@overload
	def __init__(self) -> None: ...
	def AddProtocol(self, aprotocol: Standard_Transient) -> None: ...
	def Clear(self) -> None: ...
	def Module(self) -> IGESData_SpecificModule: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Protocol(self) -> IGESData_Protocol: ...
	def Select(self, obj: IGESData_IGESEntity, module: IGESData_SpecificModule) -> Tuple[bool, int]: ...
	def SetComplete(self) -> None: ...
	@staticmethod
	def SetGlobal(amodule: IGESData_SpecificModule, aprotocol: IGESData_Protocol) -> None: ...
	def Start(self) -> None: ...

class IGESData_SpecificModule(Standard_Transient):
	def OwnCorrect(self, CN: int, ent: IGESData_IGESEntity) -> bool: ...

class IGESData_ToolLocation(Standard_Transient):
	def __init__(self, amodel: IGESData_IGESModel, protocol: IGESData_Protocol) -> None: ...
	def AnalyseLocation(self, loc: gp_GTrsf, result: gp_Trsf) -> bool: ...
	@staticmethod
	def ConvertLocation(prec: float, loc: gp_GTrsf, result: gp_Trsf, uni: Optional[float] = 1) -> bool: ...
	def EffectiveLocation(self, ent: IGESData_IGESEntity) -> gp_GTrsf: ...
	def ExplicitLocation(self, ent: IGESData_IGESEntity) -> gp_GTrsf: ...
	def HasParent(self, ent: IGESData_IGESEntity) -> bool: ...
	def HasParentByAssociativity(self, ent: IGESData_IGESEntity) -> bool: ...
	def HasTransf(self, ent: IGESData_IGESEntity) -> bool: ...
	def IsAmbiguous(self, ent: IGESData_IGESEntity) -> bool: ...
	def IsAssociativity(self, ent: IGESData_IGESEntity) -> bool: ...
	def IsTransf(self, ent: IGESData_IGESEntity) -> bool: ...
	def Load(self) -> None: ...
	def Parent(self, ent: IGESData_IGESEntity) -> IGESData_IGESEntity: ...
	def ParentLocation(self, ent: IGESData_IGESEntity) -> gp_GTrsf: ...
	def ResetDependences(self, child: IGESData_IGESEntity) -> None: ...
	def SetOwnAsDependent(self, ent: IGESData_IGESEntity) -> None: ...
	def SetParentAssoc(self, parent: IGESData_IGESEntity, child: IGESData_IGESEntity) -> None: ...
	def SetPrecision(self, prec: float) -> None: ...
	def SetReference(self, parent: IGESData_IGESEntity, child: IGESData_IGESEntity) -> None: ...

class IGESData_WriterLib:
	@overload
	def __init__(self, aprotocol: IGESData_Protocol) -> None: ...
	@overload
	def __init__(self) -> None: ...
	def AddProtocol(self, aprotocol: Standard_Transient) -> None: ...
	def Clear(self) -> None: ...
	def Module(self) -> IGESData_ReadWriteModule: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Protocol(self) -> IGESData_Protocol: ...
	def Select(self, obj: IGESData_IGESEntity, module: IGESData_ReadWriteModule) -> Tuple[bool, int]: ...
	def SetComplete(self) -> None: ...
	@staticmethod
	def SetGlobal(amodule: IGESData_ReadWriteModule, aprotocol: IGESData_Protocol) -> None: ...
	def Start(self) -> None: ...

class IGESData_ColorEntity(IGESData_IGESEntity):
	pass

class IGESData_DefaultGeneral(IGESData_GeneralModule):
	def __init__(self) -> None: ...
	def DirChecker(self, CN: int, ent: IGESData_IGESEntity) -> IGESData_DirChecker: ...
	def NewVoid(self, CN: int, entto: Standard_Transient) -> bool: ...
	def OwnCheckCase(self, CN: int, ent: IGESData_IGESEntity, shares: Interface_ShareTool, ach: Interface_Check) -> None: ...
	def OwnCopyCase(self, CN: int, entfrom: IGESData_IGESEntity, entto: IGESData_IGESEntity, TC: Interface_CopyTool) -> None: ...
	def OwnSharedCase(self, CN: int, ent: IGESData_IGESEntity, iter: Interface_EntityIterator) -> None: ...

class IGESData_DefaultSpecific(IGESData_SpecificModule):
	def __init__(self) -> None: ...

class IGESData_FileProtocol(IGESData_Protocol):
	def __init__(self) -> None: ...
	def Add(self, protocol: IGESData_Protocol) -> None: ...
	def NbResources(self) -> int: ...
	def Resource(self, num: int) -> Interface_Protocol: ...

class IGESData_LabelDisplayEntity(IGESData_IGESEntity):
	pass

class IGESData_LevelListEntity(IGESData_IGESEntity):
	def HasLevelNumber(self, level: int) -> bool: ...
	def LevelNumber(self, num: int) -> int: ...
	def NbLevelNumbers(self) -> int: ...

class IGESData_LineFontEntity(IGESData_IGESEntity):
	pass

class IGESData_NameEntity(IGESData_IGESEntity):
	def Value(self) -> TCollection_HAsciiString: ...

class IGESData_SingleParentEntity(IGESData_IGESEntity):
	def Child(self, num: int) -> IGESData_IGESEntity: ...
	def NbChildren(self) -> int: ...
	def SingleParent(self) -> IGESData_IGESEntity: ...

class IGESData_TransfEntity(IGESData_IGESEntity):
	def Value(self) -> gp_GTrsf: ...

class IGESData_UndefinedEntity(IGESData_IGESEntity):
	def __init__(self) -> None: ...
	def ChangeableContent(self) -> Interface_UndefinedContent: ...
	def DefColor(self) -> IGESData_DefType: ...
	def DefLevel(self) -> IGESData_DefList: ...
	def DefLineFont(self) -> IGESData_DefType: ...
	def DefView(self) -> IGESData_DefList: ...
	def DirStatus(self) -> int: ...
	def HasSubScriptNumber(self) -> bool: ...
	def IsOKDirPart(self) -> bool: ...
	def ReadDir(self, IR: IGESData_IGESReaderData, DP: IGESData_DirPart, ach: Interface_Check) -> bool: ...
	def ReadOwnParams(self, IR: IGESData_IGESReaderData, PR: IGESData_ParamReader) -> None: ...
	def SetNewContent(self, cont: Interface_UndefinedContent) -> None: ...
	def SetOKDirPart(self) -> None: ...
	def UndefinedContent(self) -> Interface_UndefinedContent: ...
	def WriteOwnParams(self, IW: IGESData_IGESWriter) -> None: ...

class IGESData_ViewKindEntity(IGESData_IGESEntity):
	def IsSingle(self) -> bool: ...
	def NbViews(self) -> int: ...
	def ViewItem(self, num: int) -> IGESData_ViewKindEntity: ...

class IGESData_FreeFormatEntity(IGESData_UndefinedEntity):
	def __init__(self) -> None: ...
	def AddEntities(self, ents: IGESData_HArray1OfIGESEntity) -> None: ...
	def AddEntity(self, ptype: Interface_ParamType, ent: IGESData_IGESEntity, negative: Optional[bool] = False) -> None: ...
	@overload
	def AddLiteral(self, ptype: Interface_ParamType, val: TCollection_HAsciiString) -> None: ...
	@overload
	def AddLiteral(self, ptype: Interface_ParamType, val: str) -> None: ...
	def AddNegativePointers(self, list: TColStd_HSequenceOfInteger) -> None: ...
	def ClearNegativePointers(self) -> None: ...
	def IsNegativePointer(self, num: int) -> bool: ...
	def IsParamEntity(self, num: int) -> bool: ...
	def NbParams(self) -> int: ...
	def NegativePointers(self) -> TColStd_HSequenceOfInteger: ...
	def ParamData(self, num: int, ptype: Interface_ParamType, ent: IGESData_IGESEntity, val: TCollection_HAsciiString) -> bool: ...
	def ParamEntity(self, num: int) -> IGESData_IGESEntity: ...
	def ParamType(self, num: int) -> Interface_ParamType: ...
	def ParamValue(self, num: int) -> TCollection_HAsciiString: ...
	def SetFormNumber(self, formnum: int) -> None: ...
	def SetTypeNumber(self, typenum: int) -> None: ...
	def WriteOwnParams(self, IW: IGESData_IGESWriter) -> None: ...

# harray1 classes

class IGESData_HArray1OfIGESEntity(IGESData_Array1OfIGESEntity, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> IGESData_Array1OfIGESEntity: ...

# harray2 classes
# hsequence classes

igesdata_Init = igesdata.Init
igesdata_Protocol = igesdata.Protocol
IGESData_BasicEditor_DraftingMax = IGESData_BasicEditor.DraftingMax
IGESData_BasicEditor_DraftingName = IGESData_BasicEditor.DraftingName
IGESData_BasicEditor_IGESVersionMax = IGESData_BasicEditor.IGESVersionMax
IGESData_BasicEditor_IGESVersionName = IGESData_BasicEditor.IGESVersionName
IGESData_BasicEditor_UnitFlagName = IGESData_BasicEditor.UnitFlagName
IGESData_BasicEditor_UnitFlagValue = IGESData_BasicEditor.UnitFlagValue
IGESData_BasicEditor_UnitNameFlag = IGESData_BasicEditor.UnitNameFlag
IGESData_GlobalSection_NewDateString = IGESData_GlobalSection.NewDateString
IGESData_GlobalSection_NewDateString = IGESData_GlobalSection.NewDateString
IGESData_SpecificLib_SetGlobal = IGESData_SpecificLib.SetGlobal
IGESData_ToolLocation_ConvertLocation = IGESData_ToolLocation.ConvertLocation
IGESData_WriterLib_SetGlobal = IGESData_WriterLib.SetGlobal



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.HLRBRep import *


class HLRAppli_ReflectLines:
	def __init__(self, aShape: TopoDS_Shape) -> None: ...
	def GetCompoundOf3dEdges(self, type: HLRBRep_TypeOfResultingEdge, visible: bool, In3d: bool) -> TopoDS_Shape: ...
	def GetResult(self) -> TopoDS_Shape: ...
	def Perform(self) -> None: ...
	def SetAxes(self, Nx: float, Ny: float, Nz: float, XAt: float, YAt: float, ZAt: float, XUp: float, YUp: float, ZUp: float) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

